package com.chelvc.framework.base.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import com.fasterxml.jackson.annotation.JacksonAnnotationsInside;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.chelvc.framework.base.jackson.EnumerationFormatSerializer;

/**
 * Jackson枚举对象结构化注解
 *
 * @author Woody
 * @date 2023/1/1
 */
@Inherited
@Documented
@JacksonAnnotationsInside
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.TYPE, ElementType.FIELD})
@JsonSerialize(using = EnumerationFormatSerializer.class)
public @interface Enumerate {
    /**
     * 默认编号字段名称
     */
    String DEFAULT_CODE_NAME = "code";

    /**
     * 默认描述字段名称
     */
    String DEFAULT_DESCRIPTION_NAME = "description";

    /**
     * 获取编号字段名称
     *
     * @return 编号字段名称
     */
    String codeName() default DEFAULT_CODE_NAME;

    /**
     * 获取描述字段名称
     *
     * @return 描述字段名称
     */
    String descriptionName() default DEFAULT_DESCRIPTION_NAME;

    /**
     * 版本控制
     *
     * @return 版本控制数组
     */
    Versioning[] versioning() default {};
}
