package com.chelvc.framework.sms.config;

import lombok.Data;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * 短信验证码配置属性
 *
 * @author Woody
 * @date 2023/1/1
 */
@Data
@Configuration
@ConfigurationProperties("sms.captcha")
@ConditionalOnProperty(prefix = "sms.captcha", value = "template")
public class CaptchaSmsProperties {
    /**
     * 验证码模版
     */
    private String template;

    /**
     * 验证码发送间隔时间（秒）
     */
    private Integer interval = 60;

    /**
     * 验证码有效时间（秒）
     */
    private Integer expiration = 10 * 60;

    /**
     * 验证码长度
     */
    private Length length = Length.SIX;

    /**
     * 验证码长度枚举项
     */
    public enum Length {
        /**
         * 四位
         */
        FOUR,

        /**
         * 六位
         */
        SIX;
    }
}
