package com.chelvc.framework.upload.support;

import java.io.File;
import java.io.InputStream;

import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import com.chelvc.framework.base.util.HttpUtils;
import com.chelvc.framework.common.util.FileUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.upload.UploadHandler;
import com.chelvc.framework.upload.config.StandardUploadProperties;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.stereotype.Component;

/**
 * 文件上传标准实现
 *
 * @author Woody
 * @date 2023/1/1
 */
@Component
@ConditionalOnBean(StandardUploadProperties.class)
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class StandardUploadHandler implements UploadHandler {
    private final StandardUploadProperties properties;

    @Override
    public String upload(@NonNull File file) {
        String suffix = FileUtils.getSuffix(file);
        String filename = StringUtils.uuid() + StringUtils.ifEmpty(suffix, name -> "." + name, StringUtils.EMPTY);
        FileUtils.write(new File(this.properties.getPath(), filename), file);
        return HttpUtils.url(this.properties.getDomain(), filename);
    }

    @Override
    public String upload(@NonNull InputStream stream, String suffix) {
        return this.upload(stream, suffix, FileUtils.getLength(stream));
    }

    @Override
    public String upload(@NonNull InputStream stream, String suffix, long length) {
        String filename = StringUtils.uuid() + StringUtils.ifEmpty(suffix, name -> "." + name, StringUtils.EMPTY);
        FileUtils.write(new File(this.properties.getPath(), filename), stream);
        return HttpUtils.url(this.properties.getDomain(), filename);
    }
}
